==> netCoin_0.3.2.tar.gz: netCoin/inst/www/en.js <==
// texts to translate
var texts = {
    netselection : "Graph",
    nodes : "Nodes",
    general: "General",
    links: "Links",
    apply: "Apply",
    filter: "Filter",
    select: "Select",
    clear: "Clear",
    add: "Add",
    simpleadvanced: "Simple/advanced",
    nodesattributes: "Node attributes",
    linksattributes: "Link attributes",
    noitemsselected: "No items selected",
    alertnonodes: "No nodes selected! Hold shift to select nodes.",
    alertnonodestable: "No nodes selected in table!",
    repulsion: "Repulsion",
    distance: "Distance",
    loading: "Loading...",
    pdfexport: "PDF export",
    svgexport: "SVG export",
    showhidelegend: "Show/hide legend",
    showhideaxes: "Show/hide axes",
    showhideimages: "Show/hide images",
    showhidesidebar: "Show/hide sidebar",
    stopresume: "Stop/resume",
    netheatmap: "Net/heatmap",
    isolateselection: "Filter selection",
    resetfilter: "Reset filter",
    selectall: "Select all/none",
    selectneighbors: "Add neighbors",
    egoNet: "EgoNet",
    expandcollapse: "Expand/collapse",
    tableselection: "Matched in table",
    reset: "Reset",
    directional: "Show/hide arrows",
    degree: "degree",
    none: "none",
    downloadtable: "Download table",
    total: "Total",
    concoincidences: "Conditional coincidences",
    coincidences: "Coincidences",
    ofsomeone: "of",
    withsomeone: "with",
    incidences: "Incidences",
    ltexpected: "< Expected",
    gtexpected: "> Expected",
    confidence: "Confidence interval",
    subjectselect: "Event selection",
    Label: "Label",
    Group: "Group",
    OrderA: "A Order",
    OrderD: "D Order",
    Size: "Size",
    Color: "Color",
    Shape: "Shape",
    Legend: "Legend",
    Width: "Width",
    Weight: "Weight",
    Intensity: "Intensity",
    Text: "Text",
    Show: "Show",
    Hide: "Hide",
    circle: "circle",
    cross: "cross",
    diamond: "diamond",
    square: "square",
    "triangle-down": "triangle-down",
    "triangle-up": "triangle-up",
    trianglesquare: "Triangle/square",
    selectacolorscale: "Select a color scale for ",
    outof: "out of"
  };

==> netCoin_1.1.23.tar.gz: netCoin/inst/www/en.js <==
// texts to translate
var texts = {
    netselection : "Graph",
    nodes : "Nodes",
    general: "General",
    links: "Links",
    apply: "Apply",
    filter: "Filter",
    select: "Select",
    clear: "Clear",
    add: "Add",
    simpleadvanced: "Simple/advanced",
    nodesattributes: "Node attributes",
    linksattributes: "Link attributes",
    noitemsselected: "No items selected",
    alertnonodes: "No nodes selected! Hold shift to select nodes.",
    alertnonodestable: "No nodes selected in table!",
    repulsion: "Repulsion",
    distance: "Distance",
    loading: "Loading...",
    pdfexport: "PDF export",
    svgexport: "SVG export",
    showhidelegend: "Show/hide legend",
    showhideaxes: "Show/hide axes",
    showhideimages: "Show/hide images",
    showhidesidebar: "Show/hide sidebar",
    showhidebuttons: "Show/hide buttons",
    showhidetables: "Show/hide tables",
    stopresume: "Stop/resume",
    netheatmap: "Net/heatmap",
    isolateselection: "Filter selection",
    resetfilter: "Reset filter",
    selectall: "Select all/none",
    selectneighbors: "Add neighbors",
    egoNet: "EgoNet",
    expandcollapse: "Expand/collapse",
    tableselection: "Matched in table",
    reset: "Reset",
    directional: "Show/hide arrows",
    degree: "degree",
    none: "none",
    downloadtable: "Download table",
    total: "Total",
    concoincidences: "Conditional coincidences",
    coincidences: "Coincidences",
    ofsomeone: "of",
    withsomeone: "with",
    incidences: "Incidences",
    expected: "Expected",
    expectedconfidence: "+/- Expected confidence",
    confidenceinterval: "+/- Confidence interval",
    subjectselect: "Event",
    Label: "Label",
    LabelSize: "Lab.Size",
    Group: "Group",
    Order: "Order",
    OrderA: "A Order",
    OrderD: "D Order",
    Size: "Size",
    Color: "Color",
    Shape: "Shape",
    Legend: "Legend",
    Width: "Width",
    Weight: "Weight",
    Intensity: "Intensity",
    Text: "Text",
    Show: "Show",
    Hide: "Hide",
    circle: "circle",
    cross: "cross",
    diamond: "diamond",
    square: "square",
    "triangle-down": "triangle-down",
    "triangle-up": "triangle-up",
    trianglesquare: "Triangle/square",
    selectacolorscale: "Select a color scale for ",
    outof: "out of",
    scenarios: "Number of scenarios",
    resetzoom: "Reset zoom",
    removefilter: "Remove filter",
    alertrecordheatmap: "Heatmap cannot be recorded.",
    speed: "Speed"
  };
